powered by
Add Lines to a Plot to Indicate Where the Margins Are
showMarginLines(sides = 1:4, lty = 2, ...)
Numeric vector giving the sides of the plot to annotate. Defaults to 1:4.
Argument to be passed to graphics::abline. Defaults to 2.
Other arguments to be passed to graphics::abline
Jasper Watson
if (FALSE) { plot(1:10) par(xpd = NA) showMarginLines() }
Run the code above in your browser using DataLab