Learn R Programming

precisePlacement (version 0.2.0)

showOuterMarginLines: Add Lines to a Plot to Indicate Where the Outer Margins Are

Description

Add Lines to a Plot to Indicate Where the Outer Margins Are

Usage

showOuterMarginLines(sides = 1:4, lty = 3, col = "purple", ...)

Arguments

sides

Numeric vector giving the sides of the plot to annotate. Defaults to 1:4.

lty

Argument to be passed to graphics::abline. Defaults to 3.

col

Argument to be passed to graphics::abline. Defaults to "purple".

...

Other arguments to be passed to graphics::abline

Author

Jasper Watson

Examples

Run this code
if (FALSE) {

par(oma = 1:4, mfrow = 2:1)
plot(1:10)
plot(1:10)
par(xpd = NA)
showOuterMarginLines()

}

Run the code above in your browser using DataLab